import { useEffect } from "react";
import { Stack, Container } from "react-bootstrap";
import { isEmpty } from "lodash";

import { socket } from "./socket";
import { useAppSelector } from "./hooks";
import { selectRoomCode } from "./store/commonSlice";
import { selectContestants } from "./store/displaySlice";
import { selectCategories, selectActiveClue } from "./store/cluesSlice";
import ContestantWidget from "./ContestantWidget";
import Gameboard from "./display/Gameboard";
import ClueDisplay from "./display/ClueDisplay";

const Display = () => {
  const roomCode = useAppSelector(selectRoomCode);
  const contestants = useAppSelector(selectContestants);
  const categories = useAppSelector(selectCategories);
  const activeClue = useAppSelector(selectActiveClue);

  useEffect(() => {
    socket.emit("new-game");
  }, []);

  return (
    <>
      <Container>
        <h1 className="text-center">Room code is: {roomCode}</h1>
      </Container>

      {!isEmpty(categories) && !activeClue && (
        <Gameboard categories={categories} />
      )}
      {!isEmpty(categories) && activeClue && (
        <ClueDisplay activeClue={activeClue} />
      )}

      <Stack
        direction="horizontal"
        gap={5}
        className="position-absolute bottom-0 w-100 d-flex justify-content-center"
      >
        {Object.entries(contestants).map(([sid, contestant]) => (
          <ContestantWidget key={sid} contestant={contestant} />
        ))}
      </Stack>
    </>
  );
};

export default Display;
