import { useEffect } from "react";
import { useParams } from "react-router-dom";

import { socket } from "./socket";
import { useAppSelector, useAppDispatch } from "./hooks";
import {
  selectCategories,
  selectActiveClue,
  clearActiveClue,
} from "./store/cluesSlice";
import Pregame from "./host/Pregame";
import ActiveClue from "./host/ActiveClue";
import CluesDisplay from "./host/CluesDisplay";

const Host = () => {
  const { room } = useParams();

  const dispatch = useAppDispatch();

  const activeClue = useAppSelector(selectActiveClue);
  const categories = useAppSelector(selectCategories);

  useEffect(() => {
    socket.emit("host-join", { room });
    socket.on("contestant-scores", () => dispatch(clearActiveClue()));
    socket.on("clue-clock-off", () => dispatch(clearActiveClue()));
  }, []);

  if (categories.length < 6) {
    return <Pregame />;
  } else if (activeClue) {
    return <ActiveClue activeClue={activeClue} />;
  } else {
    return <CluesDisplay />;
  }
};

export default Host;
