import { useState, useEffect } from "react";
import { Container, Stack, Button } from "react-bootstrap";

import type { Clue } from "../store/cluesSlice";
import { socket } from "../socket";
import { debounce } from "../utils";

interface Props {
  activeClue: Clue;
}

type Mode = "reading" | "running" | "buzzed";

const ActiveClue = ({ activeClue }: Props) => {
  const [mode, setMode] = useState<Mode>("reading");
  useEffect(() => {
    socket.on("clue-clock-on", () => {
      setMode("running");
    });
    socket.on("contestant-buzzed", () => {
      setMode("buzzed");
    });
  }, []);
  const startTimer = debounce(() => socket.emit("start-clue-clock"));
  const contestantCorrect = debounce(() => socket.emit("contestant-correct"));
  const contestantIncorrect = debounce(() => {
    setMode("running");
    socket.emit("contestant-incorrect");
  });
  return (
    <Container>
      <p>{activeClue.question}</p>
      <p className="fst-italic">{activeClue.answer}</p>
      <Stack gap={3} className="text-center">
        {mode === "reading" && (
          <Button onClick={startTimer}>Start Timer</Button>
        )}
        {mode === "buzzed" && (
          <>
            <Button onClick={contestantCorrect}>Correct</Button>
            <Button onClick={contestantIncorrect}>Incorrect</Button>
          </>
        )}
      </Stack>
    </Container>
  );
};

export default ActiveClue;
