import { createSlice, PayloadAction } from "@reduxjs/toolkit";
import type { RootState } from "./";

interface DisplayState {
  contestants: Record<string, Contestant>;
}

export interface Contestant {
  signature: number[][];
  score: number;
  active: boolean;
  failed: boolean;
}

const initialState: DisplayState = {
  contestants: {},
};

export const displaySlice = createSlice({
  name: "display",
  initialState,
  reducers: {
    addContestant: (
      state,
      {
        payload: { sid, signature },
      }: PayloadAction<{ sid: string; signature: number[][] }>
    ) => {
      state.contestants = {
        ...state.contestants,
        [sid]: { signature, score: 0, active: false, failed: false },
      };
    },
  },
});

export const { addContestant } = displaySlice.actions;
export const selectContestants = (state: RootState) =>
  state.display.contestants;

export default displaySlice.reducer;
